@@ -1,6 +1,6 @@
 from collections import namedtuple
 
-PrefixFunctions = namedtuple("PrefixFunctions", ['prefix', 'hasit', 'filterit', 'makeit'])
+PrefixFunctions = namedtuple("PrefixFunctions", ['prefix', 'hasit', 'filterit', 'makeit', ])
 
 def prefix_funcs(prefix):
 
@@ -16,17 +16,21 @@ def prefix_funcs(prefix):
         else:
             return prefix + x
 
+    def removeit(x):
+        if hasit(x):
+            return x.replace(prefix, '', 1)
+
     return PrefixFunctions(prefix, hasit, filterit, makeit)
 
 PrefixesFunctions = namedtuple("PrefixesFunctions", ['prefixes', 'hasem', 'filterem', 'funcs'])
 
 def prefixes_funcs(prefixes):
 
-    def hasem(x):
+    def hasone(x):
         return any((x.startswith(p) for p in prefixes))
 
     def filterem(lst):
-        return [ x for x in lst if hasem(x) ]
+        return [ x for x in lst if hasone(x) ]
 
-    return PrefixesFunctions(prefixes, hasem, filterem, [prefix_funcs(p) for p in prefixes])
+    return PrefixesFunctions(prefixes, hasone, filterem, [prefix_funcs(p) for p in prefixes])
 
